@@ -12,11 +12,11 @@
 """
 __author__ = 'liaozhaoyan'
 
+import os
 import shlex
 import re
 from collections import deque
 from .execCmd import CexecCmd
-from datetime import datetime
 
 HIST2_MAX = 65
 HIST10_MAX = 20
@@ -217,5 +217,13 @@ def transProbeLine(line):
     return res
 
 
+def taskList(pid):
+    path = "/proc/%d/task/" % pid
+    try:
+        return os.listdir(path)
+    except OSError:
+        return []
+
+
 if __name__ == "__main__":
     pass
